You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@ant.apache.org by mb...@apache.org on 2008/06/24 21:00:33 UTC

svn commit: r671298 - /ant/core/trunk/src/main/org/apache/tools/ant/types/Resource.java

Author: mbenson
Date: Tue Jun 24 12:00:33 2008
New Revision: 671298

URL: http://svn.apache.org/viewvc?rev=671298&view=rev
Log:
FileProvider changes

Modified:
    ant/core/trunk/src/main/org/apache/tools/ant/types/Resource.java

Modified: ant/core/trunk/src/main/org/apache/tools/ant/types/Resource.java
URL: http://svn.apache.org/viewvc/ant/core/trunk/src/main/org/apache/tools/ant/types/Resource.java?rev=671298&r1=671297&r2=671298&view=diff
==============================================================================
--- ant/core/trunk/src/main/org/apache/tools/ant/types/Resource.java (original)
+++ ant/core/trunk/src/main/org/apache/tools/ant/types/Resource.java Tue Jun 24 12:00:33 2008
@@ -24,6 +24,8 @@
 import java.util.Iterator;
 import java.util.NoSuchElementException;
 
+import org.apache.tools.ant.types.resources.FileProvider;
+
 /**
  * Describes a "File-like" resource (File, ZipEntry, etc.).
  *
@@ -373,12 +375,12 @@
 
     /**
      * Fulfill the ResourceCollection contract.
      * @return whether this Resource is a FileResource.
      * @since Ant 1.7
      */
     public boolean isFilesystemOnly() {
-        //default false:
-        return isReference() && ((Resource) getCheckedRef()).isFilesystemOnly();
+        return (isReference() && ((Resource) getCheckedRef()).isFilesystemOnly())
+                || this instanceof FileProvider;
     }
 
     /**
@@ -373,12 +375,12 @@
     /**
      * Fulfill the ResourceCollection contract.
-     * @return whether this Resource is a FileResource.
+     * @return whether this Resource is a FileProvider.
      * @since Ant 1.7
      */